'use client';

import {
  Box,
  Container,
  Heading,
  Text,
  VStack,
  useColorModeValue,
  StackDivider,
} from '@chakra-ui/react';

export default function TermsPage() {
  const bg = useColorModeValue('white', 'gray.800');
  const headingColor = useColorModeValue('teal.600', 'teal.300');
  const textColor = useColorModeValue('gray.700', 'gray.300');

  return (
    <Box
      minH="100vh"
      bgGradient="linear(to-br, teal.50, white)"
      py={{ base: 10, md: 20 }}
      px={{ base: 4, md: 0 }}
      display="flex"
      alignItems="center"
      justifyContent="center"
    >
      <Container maxW="7xl" bg={bg} boxShadow="2xl" borderRadius="xl" p={{ base: 8, md: 16 }}>
        <Heading
          as="h1"
          size="2xl"
          mb={8}
          fontWeight="extrabold"
          color={headingColor}
          letterSpacing="tight"
          textAlign="center"
        >
          Terms and Conditions
        </Heading>

        <VStack
          spacing={6}
          align="stretch"
          divider={<StackDivider borderColor={useColorModeValue('gray.200', 'gray.700')} />}
          color={textColor}
          fontSize="md"
          lineHeight="tall"
        >
          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              1. Introduction
            </Heading>
            <Text>
              Welcome to [Your Website]! These Terms and Conditions govern your use of our website
              and services. By accessing or using our site, you agree to be bound by these terms.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              2. Use of the Website
            </Heading>
            <Text>
              You agree to use our website only for lawful purposes and in a way that does not
              infringe the rights of, restrict, or inhibit anyone else's use and enjoyment of the
              site.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              3. Intellectual Property
            </Heading>
            <Text>
              All content, trademarks, and data on this website, including but not limited to text,
              graphics, logos, and images, are the property of [Your Website] or its licensors.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              4. Limitation of Liability
            </Heading>
            <Text>
              We are not liable for any damages that may occur from the use or inability to use the
              website or any linked resources.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              5. Changes to Terms
            </Heading>
            <Text>
              We reserve the right to update or change these terms at any time without prior
              notice. Your continued use of the site after changes signifies your acceptance of
              the updated terms.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              6. Contact Us
            </Heading>
            <Text>
              If you have any questions about these Terms, please contact us at{' '}
              <a
                href="mailto:support@yourwebsite.com"
                style={{ color: headingColor, textDecoration: 'underline' }}
              >
                support@yourwebsite.com
              </a>
              .
            </Text>
          </Box>
        </VStack>
      </Container>
    </Box>
  );
}
